aboutsummaryrefslogtreecommitdiffstats
path: root/lib
diff options
context:
space:
mode:
authorIngela Anderton Andin <[email protected]>2010-04-13 14:26:55 +0000
committerErlang/OTP <[email protected]>2010-04-13 14:26:55 +0000
commit6c2685553e136d80d78eee6eab193ba30277f01d (patch)
tree1970813c58b088cddd31235bfb2fb57e9ad1672d /lib
parente8b92d40b92142d1654994f16855922b8060a484 (diff)
downloadotp-6c2685553e136d80d78eee6eab193ba30277f01d.tar.gz
otp-6c2685553e136d80d78eee6eab193ba30277f01d.tar.bz2
otp-6c2685553e136d80d78eee6eab193ba30277f01d.zip
Fixed dialyzer warning
Diffstat (limited to 'lib')
-rw-r--r--lib/ssl/src/ssl_connection.erl4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/ssl/src/ssl_connection.erl b/lib/ssl/src/ssl_connection.erl
index 6dd05688f0..23f13c9511 100644
--- a/lib/ssl/src/ssl_connection.erl
+++ b/lib/ssl/src/ssl_connection.erl
@@ -768,7 +768,7 @@ handle_event(#alert{level = ?WARNING, description = ?NO_RENEGOTIATION} = Alert,
{stop, normal, State};
handle_event(#alert{level = ?WARNING, description = ?NO_RENEGOTIATION} = Alert, StateName,
#state{log_alert = Log, renegotiation = {true, From}} = State) when is_pid(From) ->
log_alert(Log, StateName, Alert),
gen_fsm:reply(From, {error, renegotiation_rejected}),
{next_state, connection, next_record(State)};
@@ -2121,7 +2121,7 @@ notify_senders(SendQueue) ->
gen_fsm:reply(From, {error, closed})
end, queue:to_list(SendQueue)).
-notify_renegotiater({true, From}) when is_pid(From) ->
+notify_renegotiater({true, From}) when not is_atom(From) ->
gen_fsm:reply(From, {error, closed});
notify_renegotiater(_) ->
ok.
@@ -768,7 +768,7 @@ handle_event(#alert{level = ?WARNING, description = ?NO_RENEGOTIATION} = Alert,
{stop, normal, State};
handle_event(#alert{level = ?WARNING, description = ?NO_RENEGOTIATION} = Alert, StateName,
- #state{log_alert = Log, renegotiation = {true, From}} = State) when is_pid(From) ->
+ #state{log_alert = Log, renegotiation = {true, From}} = State) when not is_atom(From) ->
log_alert(Log, StateName, Alert),
gen_fsm:reply(From, {error, renegotiation_rejected}),